@@ -161,16 +161,22 @@ package DB_File ;
 use warnings;
 use strict;
 our ($VERSION, @ISA, @EXPORT, $AUTOLOAD, $DB_BTREE, $DB_HASH, $DB_RECNO);
-our ($db_version, $use_XSLoader, $splice_end_array, $Error);
+our ($db_version, $use_XSLoader, $splice_end_array_no_length, $splice_end_array, $Error);
 use Carp;
 
 
-$VERSION = "1.819" ;
+$VERSION = "1.823" ;
 $VERSION = eval $VERSION; # needed for dev releases
 
 {
-    local $SIG{__WARN__} = sub {$splice_end_array = "@_";};
+    local $SIG{__WARN__} = sub {$splice_end_array_no_length = "@_";};
     my @a =(1); splice(@a, 3);
+    $splice_end_array_no_length = 
+        ($splice_end_array_no_length =~ /^splice\(\) offset past end of array at /);
+}      
+{
+    local $SIG{__WARN__} = sub {$splice_end_array = "@_";};
+    my @a =(1); splice(@a, 3, 1);
     $splice_end_array = 
         ($splice_end_array =~ /^splice\(\) offset past end of array at /);
 }      
@@ -342,6 +348,7 @@ sub SPLICE
 	$offset = 0;
     }
 
+    my $has_length = @_;
     my $length = @_ ? shift : 0;
     # Carping about definedness comes _after_ the OFFSET sanity check.
     # This is so we get the same error messages as Perl's splice().
@@ -371,7 +378,7 @@ sub SPLICE
     if ($offset > $size) {
  	$offset = $size;
 	warnings::warnif('misc', 'splice() offset past end of array')
-            if $splice_end_array;
+            if $has_length ? $splice_end_array : $splice_end_array_no_length;
     }
 
     # 'If LENGTH is omitted, removes everything from OFFSET onward.'
@@ -571,6 +578,20 @@ sub get_dup
 }
 
 
+sub STORABLE_freeze
+{
+    my $type = ref shift;
+    croak "Cannot freeze $type object\n";
+}
+
+sub STORABLE_thaw
+{
+    my $type = ref shift;
+    croak "Cannot thaw $type object\n";
+}
+
+
+
 1;
 __END__
 
@@ -2256,10 +2277,6 @@ All versions of Berkeley DB are available there.
 Alternatively, Berkeley DB version 1 is available at your nearest CPAN
 archive in F<src/misc/db.1.85.tar.gz>.
 
-If you are running IRIX, then get Berkeley DB version 1 from
-F<http://reality.sgi.com/ariel>. It has the patches necessary to
-compile properly on IRIX 5.3.
-
 =head1 COPYRIGHT
 
 Copyright (c) 1995-2007 Paul Marquess. All rights reserved. This program
